@@ -39,6 +39,12 @@ class Widget(AstNode):
             self.group.tokens["name"].range,
         )
 
+    def get_reference(self, _idx: int) -> T.Optional[LocationLink]:
+        if obj := self.context[ScopeCtx].objects.get(self.name):
+            return LocationLink(self.range, obj.range, obj.ranges["id"])
+        else:
+            return None
+
     @validate("name")
     def obj_widget(self):
         object = self.context[ScopeCtx].objects.get(self.tokens["name"])
@@ -88,6 +94,10 @@ class ExtSizeGroupWidgets(AstNode):
     def unique_in_parent(self):
         self.validate_unique_in_parent("Duplicate widgets block")
 
+    @docs("widgets")
+    def ref_docs(self):
+        return get_docs_section("Syntax ExtSizeGroupWidgets")
+
 
 @completer(
     applies_in=[ObjectContent],
